@@ -1,6 +1,6 @@
 import logging
 
-from webhelpers.html import literal
+from markupsafe import Markup
 
 from tg import config, request, url
 from tg.render import render
@@ -60,16 +60,23 @@ class DebugBar():
                 or 'text/html' not in response['content_type']
                 or request.headers.get(
                     'X-Requested-With') == 'XMLHttpRequest'):
+
+            if config.get('debugbar.enable_logs', False):
+                for section in __sections__:
+                    if hasattr(section, 'log_content'):
+                        section.log_content()
+
             return
+
         pos_head = page.find('</head>')
         if pos_head > 0:
             pos_body = page.find('</body>', pos_head + 7)
             if pos_body > 0:
                 response['response'] = ''.join(
                     [page[:pos_head],
-                    literal(self.css_link % url(self.css_path)),
+                    Markup(self.css_link % url(self.css_path)),
                     page[pos_head:pos_body],
-                    literal(render(dict(sections=__sections__),
+                    Markup(render(dict(sections=__sections__),
                         'genshi', self.template,).split('\n', 1)[-1]),
                     page[pos_body:]])
 
